# coding=utf-8


from penknife import msg       # MsgBox tasks
from penknife import pdf       # PDF tasks
from penknife import rpa       # Robotics tasks
from penknife import web       # Web tasks
from penknife import sys       # System tasks
from penknife import vba       # Excel e Word tasks
